Module interfaces

Module interfaces 

Service interfaces and traits

Modules

account
Account service interface
costs
Indicative costs and charges service interface Indicative costs and charges service interface for IG Markets API
listener
Listener interface for streaming data
market
Market service interface
operations
Operations/application service interface Operations service interface for IG Markets API
order
Order service interface
sentiment
Client sentiment service interface Client sentiment service interface for IG Markets API
watchlist
Watchlist service interface Watchlist service interface for IG Markets API