Module costs

Module costs 

Indicative costs and charges service interface Indicative costs and charges service interface for IG Markets API

This module defines the interface for retrieving indicative costs and charges information for opening, closing, and editing positions. This is required for regulatory compliance in certain jurisdictions.

Traits

CostsService
Service for retrieving indicative costs and charges from the IG Markets API