Core application logic and services
Modules
- auth
- Authentication and session management Authentication module for IG Markets API
- client
- Main client implementation
- config
- Application configuration module
- dynamic_
streamer - Dynamic market streamer with thread-safe subscription management Dynamic market streaming with thread-safe subscription management.
- http
- HTTP client and request execution with rate limiting and finite retry HTTP client and request execution for the IG Markets API.
- interfaces
- Service interfaces and traits
- market_
hierarchy - Market navigation hierarchy traversal helpers Market navigation hierarchy traversal.
- rate_
limiter - Rate limiter module for API request throttling Rate limiter module for controlling API request rates
- streaming_
convert - Adapters from Lightstreamer
ItemUpdateto presentation-layer DTOs Adapters from LightstreamerItemUpdateto the presentation-layer DTOs.