pub trait OperationsService: Send + Sync {
// Required methods
fn get_client_apps<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<ApplicationDetailsResponse, AppError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn disable_client_app<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<StatusResponse, AppError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Service for managing API application operations in the IG Markets API
This service provides methods for retrieving API application details and managing API key status.
Required Methods
Sourcefn get_client_apps<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<ApplicationDetailsResponse, AppError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_client_apps<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<ApplicationDetailsResponse, AppError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Returns a list of client-owned applications
Returns
Ok(ApplicationDetailsResponse)- Details of all client applicationsErr(AppError)- If the request fails
Sourcefn disable_client_app<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<StatusResponse, AppError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn disable_client_app<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<StatusResponse, AppError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Disables the current application key
Disables the current application key from processing further requests. Disabled keys may be re-enabled via the My Account section on the IG Web Dealing Platform.
Returns
Ok(StatusResponse)- The disable operation statusErr(AppError)- If the request fails