Client sentiment service interface Client sentiment service interface for IG Markets API
This module defines the interface for retrieving client sentiment data, which shows the percentage of IG clients who are long vs short on instruments.
Traits
- Sentiment
Service - Service for retrieving client sentiment data from the IG Markets API